#! /bin/bash
# This shell script check root dependencies
# i.e. that need root privileges
#
# It is intended to run on debian system
#
# This script does not altering anything
# it only check and suggest some command
# to run as root

PKGS_DB="python3-psycopg2 python3-mysqldb"
PKGS_BUILD="default-jre-headless"
PKGS_RUNTIME="redis-server"
PKGS_JOBS="libpam-systemd"

PASS_ALL_OK=0
PKG_JOBS_OK=0
MISSING_PKGS=""

check_package()
# $1 list of package
# $2 title
{
    echo "## check dependencies for $2"
    RET=0
    for PKG in $1 ; do
        echo -n "+ "
        if echo "$DPKG_LIST" | grep -q "$PKG"
        then
            echo -n "ok     "
        else
            PASS_ALL_OK=1
            RET=1
            MISSING_PKGS="${MISSING_PKGS} $PKG"
            echo -n "MISSING"
        fi
        echo " $PKG"
    done
    return $RET
}

check_user_linger()
{
    loginctl show-user $USER 2> /dev/null | grep -Eqe '^Linger=yes' || {
        PASS_ALL_OK=1
        return 1
    }
}

DPKG_LIST=$(dpkg -l)

check_package "$PKGS_DB"      "Databases"
check_package "$PKGS_BUILD"   "Build (i.e. ./manage generatemedia)"
check_package "$PKGS_RUNTIME" "Runtime (internal jobs)"
check_package "$PKGS_JOBS"    "Scheduled jobs (i.e. ./manage creme_job_manager)" || cat <<EOF

# After installing ${PKGS_JOBS},
# you may need to re-connect (su, ssh) with user $USER
# to make loginctl/cgroup working
EOF
check_user_linger || cat <<EOF

# linger not enable for user $USER, recheck after issue (as root) a

loginctl enable-linger $USER
EOF

[[ -z "$MISSING_PKGS" ]] || cat <<EOF

# install missing packages:

apt install$MISSING_PKGS
EOF

[[ "$PASS_ALL_OK" -eq 0 ]] || {
    echo
    echo "At least one dependencies test failed."
    read -p "Press enter to continue (ignore) or C-c to quit and fix it"
}
