from io import StringIO

from django.core.management import call_command

from behave import given, then, when

from center_pilote.features.utils import get_url


@given(u'je me connecte en tant que "{user}"')
def step_connexion_en_tant_que(context, user):
    browser = context.browser
    browser.visit(get_url('creme_login'))
    browser.fill('username', user)
    browser.fill('password', user)
    browser.find_by_value("Se connecter").first.click()


@when(u'je vais sur la page "{url}"')
def step_visit_view_name(context, url):
    url = get_url(url)
    context.browser.visit(url)


@then(u'je vois le titre "{text}"')
def step_je_vois_le_titre(context, text):
    assert context.browser.title == text, f"title = {context.browser.title}"


@then(u'je vois le code de retour "{text}"')
def step_je_vois_le_code_de_retour(context, text):
    status_code = context.browser.status_code.code
    assert status_code == int(text), f"code = {status_code}"


@then(u'je vois le texte "{text}"')
def step_search_in_page(context, text):
    context.test.assertContains(context.res, text)


@then(u'je vois "{text}" dans les erreurs')
def check_errorlist(context, text):
    errorlist = "".join(
        [elm.value for elm in context.browser.find_by_css('.errorlist')]
    )
    assert text in errorlist, f"{text} not in {errorlist}"


@given(u'toutes les applications pré-peuplées')
def step_populate_all(context):
    context.out = out = StringIO()
    call_command('creme_populate', stdout=out)
    assert 'Populate is OK' in out.getvalue()


@given(u'les applications "{apps}" pré-peuplées')
def step_populate(context, apps):
    context.out = out = StringIO()
    call_command('creme_populate', *apps.split(','), stdout=out)
    assert 'Populate is OK' in out.getvalue()
