from behave import given, then, when

from center_pilote.features.utils import get_fields_from_text, get_url
from center_pilote.pilote_extended.models import Organisation
from center_pilote.pilote_extended.tests.factories import OrganisationFactory


@given(u'une organisation "{name}" avec "{fields}"')
def step_def_org(context, name, fields):
    fields = get_fields_from_text(fields)
    fields['name'] = name
    context.orgs = getattr(context, "orgs", {})
    context.orgs[name] = OrganisationFactory.create(**fields)


@when(u'je vais sur la page qui fusionne "{org1}" avec "{org2}"')
def step_merge_form(context, org1, org2):
    assert hasattr(context, 'orgs'), 'orgs non initialisé'
    assert org1 in context.orgs, f'org [{org1}] not in [{context.orgs}]'
    assert org2 in context.orgs, f'org [{org2}] not in [{context.orgs}]'
    qdict = {
        'id1': context.orgs[org1].id,
        'id2': context.orgs[org2].id,
    }
    url = get_url('creme_core__merge_entities', qdict=qdict)
    context.browser.visit(url)
    title = context.browser.title
    assert title == 'Fusionner - Creme CRM', title


@when(u'je choisis "{text}" comme nom')
def step_chose_name(context, text):
    context.browser.fill('name_merged', text)


@when(u'je clique sur Fusionner')
def step_merge_valid(context):
    browser = context.browser
    browser.find_by_value("Fusionner").first.click()
    errorlist = [elm.value for elm in browser.find_by_css(".errorlist")]
    assert not errorlist, errorlist


@then(u'il y a "{text}" organisation en base')
def step_check_nb_org(context, text):
    exp_nb = int(text)
    context.orgs['res'] = all_orgs = Organisation.objects.all()
    base_nb = len(all_orgs)
    assert exp_nb == base_nb, f"{exp_nb} != {base_nb}"


@then(u'les champs de cette organisation sont "{text}"')
def step_check_fields(context, text):
    fields = get_fields_from_text(text)
    org_res = context.orgs['res'].first()
    for key, value in fields.items():
        real_value = str(getattr(org_res, key))
        assert real_value == value, f"org.{key} = {real_value}, not {value}"
