# -*- coding: utf-8 -*-

from django.db.models import (
    BooleanField,
    CharField,
    DecimalField,
    ForeignKey,
    ManyToManyField,
    PositiveIntegerField,
)
from django.urls import reverse

from creme.creme_core import models as creme_models


class InfraBoisNrj(creme_models.CremeEntity):
    class Meta:
        app_label = 'filiere_bois'
        verbose_name = "Infra bois énergie"
        verbose_name_plural = "Infras bois énergie"
        ordering = ('name',)
        unique_together = [('name', 'lieu_installation')]

    import_id = PositiveIntegerField(
        "ID temporaire d'import",
        blank=True,
        null=True,
        unique=True,
        db_index=True,
    )
    name = CharField("intitulé", max_length=256, blank=False).set_tags(
        optional=True
    )
    type_infra = ForeignKey(
        'info_tables.TypeInfra',
        on_delete=creme_models.CREME_REPLACE,
        verbose_name="Type d'infrastructure",
    ).set_tags(optional=False)
    type_plateform = BooleanField(
        "Plateforme physique",
        null=True,
        blank=True,
    ).set_tags(optional=True)
    vol_commercial_an = PositiveIntegerField(
        "Volume commercialisés (T/an)", null=True, blank=True
    ).set_tags(optional=True)
    commune = CharField("Commune", max_length=256, blank=True).set_tags(
        optional=True
    )
    annee_mise_en_service = PositiveIntegerField(
        "Année de mise en service", blank=True, null=True
    ).set_tags(optional=True)
    puissance_bois = PositiveIntegerField(
        "Puissance bois kW", blank=True, null=True
    ).set_tags(optional=True)
    energie_bois = PositiveIntegerField(
        "Energie produite bois MWh", blank=True, null=True
    ).set_tags(optional=True)
    tonnes_bois_consommees = PositiveIntegerField(
        "T de bois consommées", blank=True, null=True
    ).set_tags(optional=True)
    puissance_appoint = PositiveIntegerField(
        "Puissance appoint kW", blank=True, null=True
    ).set_tags(optional=True)
    energie_appoint = PositiveIntegerField(
        "Energie appoint MWh", blank=True, null=True
    ).set_tags(optional=True)
    tonnage_plaquette_forestiere = PositiveIntegerField(
        "Tonnage plaquette forestière", blank=True, null=True
    ).set_tags(optional=True)
    tonnage_dechet_bois_cla = PositiveIntegerField(
        "Tonnage déchet bois classe A", blank=True, null=True
    ).set_tags(optional=True)
    tonnage_dechet_bois_clb = PositiveIntegerField(
        "Tonnage déchet bois classe B", blank=True, null=True
    ).set_tags(optional=True)
    tonnage_plaquette_bocagere = PositiveIntegerField(
        "Tonnage plaquette bocagère", blank=True, null=True
    ).set_tags(optional=True)
    tonnage_cnx_scierie = PositiveIntegerField(
        "Tonnage connexe scierie", blank=True, null=True
    ).set_tags(optional=True)
    marque_chaudiere = CharField(
        "Marque chaudière", max_length=256, blank=True
    ).set_tags(optional=True)
    lng_reseau = PositiveIntegerField(
        "Longueur du réseau m", blank=True, null=True
    ).set_tags(optional=True)
    nb_ss_stations = PositiveIntegerField(
        "Nb sous stations", blank=True, null=True
    ).set_tags(optional=True)
    tep_bois_an = PositiveIntegerField(
        "TEP bois /an", blank=True, null=True
    ).set_tags(optional=True)
    type_bat_chauffes = CharField(
        "Type batiment chauffés", max_length=256, blank=True
    ).set_tags(optional=True)
    cout_tot_projet = PositiveIntegerField(
        "Cout total projet", blank=True, null=True
    ).set_tags(optional=True)
    cout_raccordement = PositiveIntegerField(
        "Cout fourniture/installation/raccordement chaudière",
        blank=True,
        null=True,
    ).set_tags(optional=True)
    cout_genie_civil = PositiveIntegerField(
        "Cout génie civil chaufferie/silo/accès", blank=True, null=True
    ).set_tags(optional=True)
    cout_reseau_ss_stations = PositiveIntegerField(
        "Cout réseau sous stations", blank=True, null=True
    ).set_tags(optional=True)
    frais_ing = PositiveIntegerField(
        "Frais d'ingénierie", blank=True, null=True
    ).set_tags(optional=True)
    montant_subv = PositiveIntegerField(
        "Montant subventions", blank=True, null=True
    ).set_tags(optional=True)
    montant_aide_ademe = PositiveIntegerField(
        "Montant aide ADEME", blank=True, null=True
    ).set_tags(optional=True)
    intensite_aide_ademe = PositiveIntegerField(
        "Intensité aide ADEME (%)", blank=True, null=True
    ).set_tags(optional=True)
    montant_aide_region = PositiveIntegerField(
        "Montant aide région", blank=True, null=True
    ).set_tags(optional=True)
    intensite_aide_region = PositiveIntegerField(
        "Intensité aide région (%)", blank=True, null=True
    ).set_tags(optional=True)
    montant_aide_europe = PositiveIntegerField(
        "Montant aide europe", blank=True, null=True
    ).set_tags(optional=True)
    intensite_aide_europe = PositiveIntegerField(
        "Intensité aide europe (%)", blank=True, null=True
    ).set_tags(optional=True)
    intensite_aide_totale = PositiveIntegerField(
        "Intensité aide totale (%)", blank=True, null=True
    ).set_tags(optional=True)
    prix_combustible_in = PositiveIntegerField(
        "Prix combustible entrée", blank=True, null=True
    ).set_tags(optional=True)
    prix_maintenance = PositiveIntegerField(
        "Prix maintenance", blank=True, null=True
    ).set_tags(optional=True)
    cout_revient_nrj_produite = PositiveIntegerField(
        "Cout de revient de l'energie produite", blank=True, null=True
    ).set_tags(optional=True)
    reseau_chaleur_vente_nrj = BooleanField(
        "Réseau de chaleur avec vente d'énergie", blank=True, null=True
    ).set_tags(optional=True)
    emissions_t_co2_an_evites = PositiveIntegerField(
        "Emissions T CO2/an évités", blank=True, null=True
    ).set_tags(optional=True)
    etp_affectes_projet = DecimalField(
        "ETP affectés au projet",
        blank=True,
        null=True,
        decimal_places=1,
        max_digits=4,
    ).set_tags(optional=True)
    etp_crees = DecimalField(
        "ETP créés", blank=True, null=True, decimal_places=1, max_digits=4
    ).set_tags(optional=True)

    lieu_installation = ForeignKey(
        'pilote_extended.Organisation',
        verbose_name="Lieu d'installation",
        blank=True,
        null=True,
        on_delete=creme_models.CREME_REPLACE,
    ).set_tags(optional=True)

    departement = ForeignKey(
        'info_tables.SecteurIntervention',
        verbose_name="Département",
        blank=True,
        null=True,
        on_delete=creme_models.CREME_REPLACE,
    ).set_tags(optional=True)
    statut_port_proj = ForeignKey(
        'info_tables.StatutPorteurProjet',
        verbose_name="Statut porteur de projet",
        blank=True,
        null=True,
        on_delete=creme_models.CREME_REPLACE,
    ).set_tags(optional=True)
    maitre_ouvrage = ForeignKey(
        'pilote_extended.Organisation',
        verbose_name="Maitre d'ouvrage",
        blank=True,
        null=True,
        related_name='organisation_maitre_ouvrage_set',
        on_delete=creme_models.CREME_REPLACE,
    ).set_tags(optional=True)
    type_installation = ForeignKey(
        'info_tables.TypeInstallation',
        verbose_name="Type d'installation",
        blank=True,
        null=True,
        on_delete=creme_models.CREME_REPLACE,
    ).set_tags(optional=True)
    montage_juridique = ForeignKey(
        'info_tables.MontageJuridique',
        verbose_name="Montage juridique",
        blank=True,
        null=True,
        on_delete=creme_models.CREME_REPLACE,
    ).set_tags(optional=True)
    etat_avancement = ForeignKey(
        'info_tables.EtatAvancement',
        verbose_name="Etat d'avancement",
        blank=True,
        null=True,
        on_delete=creme_models.CREME_REPLACE,
    ).set_tags(optional=True)
    approvisionne_par = ForeignKey(
        'pilote_extended.Organisation',
        verbose_name="Approvisionné par",
        blank=True,
        null=True,
        on_delete=creme_models.CREME_REPLACE,
        related_name='organisation_approvisionner_par_set',
    ).set_tags(optional=True)
    mode_livraison = ForeignKey(
        'info_tables.ModeLivraison',
        verbose_name="Mode de livraison",
        blank=True,
        null=True,
        on_delete=creme_models.CREME_REPLACE,
    ).set_tags(optional=True)
    type_bois_livre = ForeignKey(
        'info_tables.TypeBoisLivre',
        verbose_name="Type de bois livré",
        blank=True,
        null=True,
        on_delete=creme_models.CREME_REPLACE,
    ).set_tags(optional=True)
    qualite_bois_livre = ForeignKey(
        'info_tables.QualiteBoisLivre',
        verbose_name="Qualité du bois livré",
        blank=True,
        null=True,
        on_delete=creme_models.CREME_REPLACE,
    ).set_tags(optional=True)
    nature_appoint = ForeignKey(
        'info_tables.NatureAppoint',
        verbose_name="Nature de l'appoint",
        blank=True,
        null=True,
        on_delete=creme_models.CREME_REPLACE,
    ).set_tags(optional=True)
    type_combustible_bois = ManyToManyField(
        'info_tables.TypeCombustibleBois',
        verbose_name="Type de combustible bois",
        blank=True,
    ).set_tags(optional=True)
    num_icpe = ManyToManyField(
        'info_tables.NumIcpe',
        verbose_name="Num. ICPE",
        blank=True,
    ).set_tags(optional=True)
    statut_icpe = ForeignKey(
        'info_tables.StatutIcpe',
        verbose_name="Statut ICPE",
        blank=True,
        null=True,
        on_delete=creme_models.CREME_REPLACE,
    ).set_tags(optional=True)
    tech_filtre_fumee = ForeignKey(
        'info_tables.TechFiltreFumee',
        verbose_name="Technique de filtrage de fumées",
        blank=True,
        null=True,
        on_delete=creme_models.CREME_REPLACE,
    ).set_tags(optional=True)

    def __str__(self):
        return f"{self.name}"

    @staticmethod
    def get_lv_absolute_url():
        return reverse('filiere_bois__list_infraboisnrj')

    @staticmethod
    def get_create_absolute_url():
        return reverse('filiere_bois__create_infraboisnrj')

    def get_absolute_url(self):
        return reverse('filiere_bois__view_infraboisnrj', args=(self.id,))

    def get_edit_absolute_url(self):
        return reverse('filiere_bois__edit_infraboisnrj', args=(self.id,))
