import json

from django.urls import reverse

import pytest

from .factories import ActiviteFactory, OrganisationFactory

SECRET_TOKEN = 'my_secret_token'

# pytestmark = pytest.mark.wip


def test_json_activites_bad_conf(client, settings):
    delattr(settings, 'TOKEN_BOIS_ET_VOUS')
    url = reverse('filiere_bois__portail_bois_et_vous_activite')
    with pytest.warns(UserWarning):
        result = client.get(url, {'token': 'no_good_token'})
    assert result.get('Content-Type') == 'application/json'
    assert result.status_code == 403


def test_json_activites_bad_auth(client, settings):
    settings.TOKEN_BOIS_ET_VOUS = SECRET_TOKEN
    url = reverse('filiere_bois__portail_bois_et_vous_activite')
    result = client.get(url, {'token': 'no_good_token'})
    assert result.get('Content-Type') == 'application/json'
    assert result.status_code == 403


@pytest.mark.django_db
def test_json_activites(client, settings):
    settings.TOKEN_BOIS_ET_VOUS = SECRET_TOKEN
    ActiviteFactory(name='activite_A')
    url = reverse('filiere_bois__portail_bois_et_vous_activite')
    result = client.get(url, {'token': SECRET_TOKEN})
    assert result.status_code == 200
    json_result = json.loads(result.content)
    assert json_result['count'] == 1
    assert set(json_result['values'][0]) == set(['id', 'name', 'groupe__name'])
    assert json_result['values'][0]['name'] == 'activite_A'


@pytest.mark.django_db
def test_json_annuaire_empty(client, settings):
    settings.TOKEN_BOIS_ET_VOUS = SECRET_TOKEN
    OrganisationFactory(name='org_A', annuaire_portail=True)
    url = reverse('filiere_bois__portail_bois_et_vous')
    result = client.get(url, {'token': SECRET_TOKEN})
    assert result.status_code == 200
    json_result = json.loads(result.content)
    assert json_result['count'] == 1
    assert set(json_result['values'][0]) == {
        'id',
        'name',
        'email',
        'siret',
        'naf',
        'phone',
        'adherent',
        'city',
        'address',
        'zipcode',
        'latitude',
        'longitude',
        'geo_status',
        'website',
        'activite_pri',
        'activite_sec',
    }
    assert json_result['values'][0]['name'] == 'org_A'
