# -*- coding: utf-8 -*-

import warnings

from django.conf import settings
from django.http import JsonResponse
from django.views.generic import View

from center_pilote.info_tables.models import Activite
from center_pilote.pilote_extended.models import Organisation


class BasePortailBoisEtVous(View):
    def get_data(self):  # pragma: no cover
        return {}

    def get(self, request, *args, **kwargs):
        get_token = request.GET.get('token')
        cnf_token = getattr(settings, 'TOKEN_BOIS_ET_VOUS', None)
        if cnf_token is None:
            warnings.warn("TOKEN_BOIS_ET_VOUS not set")
        if cnf_token is None or get_token != cnf_token:
            return JsonResponse({'error': 'Unknown token'}, status=403)
        data = self.get_data()
        count = len(data)
        return JsonResponse({'count': count, 'values': data})


class PortailBoisEtVous(BasePortailBoisEtVous):
    def get_data(self):
        return Organisation.objects.directory_as_list_of_dict()


class ActiviteView(BasePortailBoisEtVous):
    def get_data(self):
        return list(Activite.objects.values('id', 'name', 'groupe__name'))
