# -*- coding: utf-8 -*-

from django.db import models
from django.urls import reverse

from creme.creme_core import models as creme_models
from creme.creme_core.models import fields as creme_fields


class Adhesion(creme_models.CremeModel):
    class Meta:
        app_label = 'info_tables'
        verbose_name = "Historique d'adhésion"
        verbose_name_plural = "Historique des adhésions"
        unique_together = [('entity', 'entity_content_type', 'annee')]
        ordering = ('-annee',)

    creation_label = 'Ajouter des adhésions'
    save_label = 'Enregister les adhésions'

    annee = models.PositiveIntegerField("Année")
    type_adhesion = models.ForeignKey(
        'info_tables.TypeAdhesion',
        verbose_name="Type d'adhésion",
        on_delete=creme_models.CREME_REPLACE,
        null=True,
        blank=True,
    )
    entity_content_type = creme_fields.EntityCTypeForeignKey(
        related_name='+', editable=False
    )
    entity = models.ForeignKey(
        creme_models.CremeEntity,
        related_name='info_tables_adhesions',
        editable=False,
        on_delete=models.CASCADE,
    ).set_tags(viewable=False)
    creme_entity = creme_fields.RealEntityForeignKey(
        ct_field='entity_content_type',
        fk_field='entity',
    )

    def __str__(self):
        # NB: translate for unicode can not take 2 arguments...
        return "[{}] {}".format(self.annee, self.type_adhesion.name)

    def get_edit_absolute_url(self):
        return reverse('info_tables__edit_adhesion', args=(self.id,))

    def get_related_entity(self):  # For generic views
        return self.creme_entity


class TypeAdhesion(creme_models.CremeModel):
    name = models.CharField("intitulé", max_length=256, blank=False)
    is_custom = models.BooleanField(default=True).set_tags(viewable=False)
    order = creme_fields.BasicAutoField("Ordre")

    class Meta:
        app_label = 'info_tables'
        verbose_name = "Type d'adhésion"
        verbose_name_plural = "Types d'adhésions"
        ordering = ('order',)

    def __str__(self):
        return self.name
