# -*- coding: utf-8 -*-
from django.conf import settings

from creme import persons
from creme.creme_core.management.commands.creme_populate import BasePopulator
from creme.creme_core.models import BrickDetailviewLocation

from . import bricks, constants, models


class Populator(BasePopulator):
    dependencies = ['creme_core', 'persons']
    overwrite = settings.POPULATE_OVERWRITE

    def __init__(self, *args, **kwargs):
        self.Organisation = persons.get_organisation_model()
        self.Contact = persons.get_contact_model()
        return super().__init__(*args, **kwargs)

    def _simple_populate(self, modelname, constantname):
        model_class = getattr(models, modelname)
        already_populated = model_class.objects.exists()
        if already_populated:
            return
        CONSTANT = getattr(constants, constantname)
        model_class.objects.bulk_create(
            (model_class(name=name, is_custom=False) for name in CONSTANT)
        )

    @staticmethod
    def _norm2dict(elm):
        if isinstance(elm, dict):
            return elm
        elif hasattr(elm, '_asdict'):
            return elm._asdict()

    def _dict_populate(self, modelname, constantname, MODELS):
        model_class = getattr(MODELS, modelname)
        already_populated = model_class.objects.exists()
        if already_populated:
            return
        CONSTANT = getattr(constants, constantname)
        model_class.objects.bulk_create(
            (model_class(**self._norm2dict(elm)) for elm in CONSTANT)
        )

    def _populate_activite(self):
        model_class = models.Activite
        already_populated = model_class.objects.exists()
        if already_populated:
            return
        gname2id = dict(
            models.GroupeActivite.objects.values_list('name', 'id')
        )
        model_class.objects.bulk_create(
            (
                model_class(
                    groupe_id=gname2id[groupe_name], name=name, is_custom=False
                )
                for groupe_name, name_list in constants.ACTIVITE.items()
                for name in name_list
            )
        )

    def _populate_bricks(self):
        if self.overwrite:
            BrickDetailviewLocation.objects.filter(
                brick_id=bricks.AdhesionsBrick.id_
            ).delete()
        LEFT = BrickDetailviewLocation.LEFT
        BrickDetailviewLocation.objects.multi_create(
            defaults={'model': self.Organisation, 'zone': LEFT},
            data=[
                {'brick': bricks.AdhesionsBrick, 'order': 10},
            ],
        )
        BrickDetailviewLocation.objects.multi_create(
            defaults={'model': self.Contact, 'zone': LEFT},
            data=[
                {'brick': bricks.AdhesionsBrick, 'order': 121},
            ],
        )

    def populate(self):
        for modelname, constantname in constants.SIMPLE_POPULATE_LIST:
            self._simple_populate(modelname, constantname)
        for modelname, constantname in constants.DICT_POPULATE_LIST:
            self._dict_populate(modelname, constantname, models)
        self._populate_activite()
        self._populate_bricks()
