from django.contrib.contenttypes.models import ContentType

import pytest
from creme.creme_core.models import CremeUser
from creme.persons import get_organisation_model

from center_pilote.info_tables.forms.adhesion import AdhesionForm
from center_pilote.info_tables.models.adhesion import Adhesion, TypeAdhesion


@pytest.mark.parametrize(
    'test_doublon, exp_error',
    [
        pytest.param(False, '', id="simple"),
        pytest.param(
            True,
            "Un object Historique d'adhésion avec ces champs Entity,"
            " Entity content type et Année existe déjà.",
            id="error_with_doublon",
        ),
    ],
)
@pytest.mark.django_db
def test_adhesionform(test_doublon, exp_error):
    user = CremeUser.objects.create(username='user0')
    org_model = get_organisation_model()
    ct_id = ContentType.objects.get_for_model(org_model).id

    type_adh = TypeAdhesion.objects.create(name="type_adh_0")
    org = org_model.objects.create(name='orga', user_id=1)
    if test_doublon:
        Adhesion.objects.create(
            type_adhesion=type_adh,
            entity_content_type_id=ct_id,
            entity_id=org.id,
            annee=2020,
        )
        org.save()
    form = AdhesionForm(
        data={'type_adhesion': type_adh.id, 'annee': 2020},
        entity=org,
        user=user.id,
    )
    assert form.is_bound
    form.is_valid()
    error_string = form.errors.get('__all__', [''])[0]
    assert error_string == exp_error
