from functools import partial

from creme import persons
from creme.creme_core.apps import CremeAppConfig


class PiloteExtendedConfig(CremeAppConfig):
    name = 'center_pilote.pilote_extended'
    verbose_name = "Pilote Extented"
    dependencies = ['creme.persons']
    extended_app = 'creme.persons'
    credentials = CremeAppConfig.CRED_NONE

    def all_apps_ready(self, *args, **kwargs):
        self.Organisation = persons.get_organisation_model()
        self.Contact = persons.get_contact_model()
        super().all_apps_ready(*args, **kwargs)
        from . import signals  # noqa

    def register_bricks(self, brick_registry):
        from . import bricks

        brick_registry.register(*bricks.bricks_list).register_hat(
            self.Organisation,
            secondary_brick_classes=(bricks.MyOrganisationCardHatBrick,),
        ).register_hat(
            self.Contact,
            secondary_brick_classes=(bricks.MyContactCardHatBrick,),
        )

    def register_function_fields(self, function_field_registry):
        from . import function_fields as ff

        reg_org = partial(function_field_registry.register, self.Organisation)
        reg_cnt = partial(function_field_registry.register, self.Contact)
        reg_org(ff.IsAdherentField)
        reg_org(ff.AnneeAdhesionField)
        reg_org(ff.TypeAdhesionField)
        reg_org(ff.RelIsManagerField)
        reg_org(ff.RelIsEmployeeField)
        reg_cnt(ff.RelManageField)
        reg_cnt(ff.RelIsEmployedByField)
