import logging
from collections import namedtuple

from creme.persons.constants import (
    REL_OBJ_EMPLOYED_BY,
    REL_OBJ_MANAGES,
    REL_SUB_EMPLOYED_BY,
    REL_SUB_MANAGES,
)

from .relations import *  # noqa

logger = logging.getLogger(__name__)

DICT_POPULATE_LIST = (
    ('StaffSize', 'STAFF_SIZE'),
    ('LegalForm', 'LEGAL_FORM'),
)

StaffSizeT = namedtuple('StaffSizeT', 'size')
STAFF_SIZE = (
    StaffSizeT("0"),
    StaffSizeT("1 - 2"),
    StaffSizeT("3 - 5"),
    StaffSizeT("6 - 9"),
    StaffSizeT("10 - 19"),
    StaffSizeT("20 - 49"),
    StaffSizeT("50 - 99"),
    StaffSizeT("100 - 199"),
    StaffSizeT("200 - 249"),
    StaffSizeT("250 - 499"),
    StaffSizeT(">= 500"),
)

LegalFormT = namedtuple('LegalFormT', 'title')
LEGAL_FORM = (
    LegalFormT("Micro-entreprise"),
    LegalFormT("SAS"),
    LegalFormT("SARL"),
    LegalFormT("SASU"),
    LegalFormT("EURL"),
    LegalFormT("EI"),
    LegalFormT("EIRL"),
    LegalFormT("Association"),
    LegalFormT("SCI "),
    LegalFormT("SA "),
    LegalFormT("Syndicat patronal"),
    LegalFormT("GIE"),
    LegalFormT("Groupement forestier"),
    LegalFormT("Ordre professionnel"),
    LegalFormT("SARL unipersonnelle"),
    LegalFormT("SNC"),
)

POP_ACTIVITYTYPE = {
    'activities-activitytype_rdv-tel': {
        'name': "Rendez-vous téléphonique",
        'default_day_duration': 0,
        'default_hour_duration': '00:30:00',
    },
    'activities-activitytype_rdv-org': {
        'name': "Rendez-vous entreprise",
        'default_day_duration': 0,
        'default_hour_duration': '01:00:00',
    },
    'activities-activitytype_rdv-inst': {
        'name': "Rendez-vous institutionnel",
        'default_day_duration': 0,
        'default_hour_duration': '01:00:00',
    },
    'activities-activitytype_acc-ind': {
        'name': "Accompagnement individuel",
        'default_day_duration': 0,
        'default_hour_duration': '01:00:00',
    },
    'activities-activitytype_acc-col': {
        'name': "Accompagnement collectif",
        'default_day_duration': 0,
        'default_hour_duration': '02:00:00',
    },
    'activities-activitytype_suivi-proj': {
        'name': "Suivi de projet prescription",
        'default_day_duration': 0,
        'default_hour_duration': '01:00:00',
    },
    'activities-activitytype_evt-bv': {
        'name': "Evénement bois et vous",
        'default_day_duration': 1,
        'default_hour_duration': '00:00:00',
    },
    'activities-activitytype_evt-adh': {
        'name': "Evénements adhérents",
        'default_day_duration': 1,
        'default_hour_duration': '00:00:00',
    },
    'activities-activitytype_evt-vst': {
        'name': "Evénements visites",
        'default_day_duration': 0,
        'default_hour_duration': '01:00:00',
    },
    'activities-activitytype_cour-pres': {
        'name': "Courrier prescription",
        'default_day_duration': 0,
        'default_hour_duration': '00:15:00',
    },
    'activities-activitytype_int-ext': {
        'name': "Intervention externe",
        'default_day_duration': 0,
        'default_hour_duration': '00:30:00',
    },
    'activities-activitytype_form': {
        'name': "Formation",
        'default_day_duration': 1,
        'default_hour_duration': '00:00:00',
    },
}

MY_HFILTER_ORGA = 'pilote_extended-hf_organisation'

try:
    from .relations import (
        ROLE_OBJ_RESPONSABLES,
        ROLE_OBJ_SALARIE,
        ROLE_SUB_RESPONSABLES,
        ROLE_SUB_SALARIE,
    )
except ImportError:  # pragma: no cover
    logger.error(
        "Use manage.py gen_relations to generate "
        "pilote_extended/constants/relations.py"
    )
    ROLE_SUB_RESPONSABLES = set()
    ROLE_SUB_SALARIE = set()
    ROLE_OBJ_RESPONSABLES = set()
    ROLE_OBJ_SALARIE = set()

ROLE_EMPLOYERS_PART = {
    *ROLE_OBJ_RESPONSABLES,
    *ROLE_OBJ_SALARIE,
}
ROLE_SUB_RESPONSABLES.add(REL_SUB_MANAGES)
ROLE_SUB_SALARIE.add(REL_SUB_EMPLOYED_BY)
ROLE_OBJ_RESPONSABLES.add(REL_OBJ_MANAGES)
ROLE_OBJ_SALARIE.add(REL_OBJ_EMPLOYED_BY)

ROLE_EMPLOYERS = ROLE_EMPLOYERS_PART.union(
    {REL_OBJ_MANAGES, REL_OBJ_EMPLOYED_BY}
)

ALLOWED_REL_TYPE_SYM_SET = {
    'ROLE_OBJ_RESPONSABLES',
    'ROLE_OBJ_SALARIE',
}
