from datetime import datetime

from django.core.management.base import BaseCommand
from django.utils.text import slugify

TEMPLATE_HEADER = "# file generated at {timestamp}\n# from file {filename}\n\n"
TEMPLATE_CONST = "{REL_SUB} = {id_sub}\n{REL_OBJ} = {id_obj}\n\n"
TEMPLATE_LIST_HEADER = "SIMPLE_RELATIONS_LIST = [\n"
TEMPLATE_LIST = (
    "    (\n"
    "        ({REL_SUB}, {label_sub}),\n"
    "        ({REL_OBJ}, {label_obj}),\n"
    "    ),\n"
)
TEMPLATE_LIST_FOOTER = "]\n"


def parse_file(infile, filename):
    timestamp = datetime.now().strftime('%Y-%m-%d %H:%M')
    buf_const = ""
    buf_list = "\n"
    buf_list += TEMPLATE_LIST_HEADER
    role_sub_dict = {}
    role_obj_dict = {}
    for line in infile:
        try:
            sline, role = line.split('\t', 1)
        except ValueError:
            sline = line
            role = 'NA'
        role = role.strip()
        role = slugify(role).replace('-', '_').upper()
        sline = sline.strip()  # striped line
        slug = slugify(sline).replace('-', '_')
        uslug = slug.upper()  # upper case slug
        REL_SUB = f"REL_SUB_{uslug}"
        REL_OBJ = f"REL_OBJ_{uslug}"
        id_sub = f"'pilote_extended-subject_{slug}'"
        id_obj = f"'pilote_extended-object_{slug}'"
        label_sub = f"\"est un {sline} de\""
        label_obj = f"\"a pour {sline}\""
        buf_const += TEMPLATE_CONST.format(**locals())
        buf_list += TEMPLATE_LIST.format(**locals())
        role_sub_list = role_sub_dict.get(role, [])
        role_sub_list.append(REL_SUB)
        role_sub_dict[role] = role_sub_list
        role_obj_list = role_obj_dict.get(role, [])
        role_obj_list.append(REL_OBJ)
        role_obj_dict[role] = role_obj_list
    buf_list += TEMPLATE_LIST_FOOTER
    for key, values in role_sub_dict.items():
        buf_list += f"\nROLE_SUB_{key} = {{\n"
        buf_list += "\n".join([f"    {val}," for val in values])
        buf_list += "\n}\n"
    for key, values in role_obj_dict.items():
        buf_list += f"\nROLE_OBJ_{key} = {{\n"
        buf_list += "\n".join([f"    {val}," for val in values])
        buf_list += "\n}\n"
    return TEMPLATE_HEADER.format(**locals()) + buf_const + buf_list


class Command(BaseCommand):
    help = (
        'generate constant file for relations, output result on stdout '
        'use with something like ">> constants.py" '
        'or "> constants_relation.py"'
    )

    def add_arguments(self, parser):
        parser.add_argument('file', nargs=None, type=str)

    def handle(self, *args, **options):
        filename = options['file']
        with open(filename, 'r') as infile:
            self.stdout.write(parse_file(infile, filename))
