from django.apps import apps
from django.core.management.base import BaseCommand

from ..check_uniq import get_dupe_list


class Command(BaseCommand):
    help = (
        "check for uniqness of field in a given model."
        " For example, to get the list of duplicate in"
        " the field 'siret' of the pilote_extended.Organisation,"
        " "
    )

    def add_arguments(self, parser):
        parser.add_argument(
            'appname', nargs=None, type=str, help="App to consider"
        )
        parser.add_argument(
            'modelname', nargs=None, type=str, help="Model to consider"
        )
        parser.add_argument(
            'fieldname', nargs=None, type=str, help="field in the model"
        )
        parser.add_argument(
            '--empty-value',
            type=str,
            help="empty value, excluded from duplicate list",
        )

    def handle(self, *args, **options):
        appname = options['appname'].lower()
        modelname = options['modelname'].lower()
        fieldname = options['fieldname']
        empty_value = options['empty_value']

        model = apps.get_model(appname, model_name=modelname)
        dupe_list = get_dupe_list(model, fieldname, empty_value)
        print(f" occ {appname}.{modelname}.{fieldname}")
        print("-----------------------")
        print("\n".join([f"{count:4} [{obj}]" for obj, count in dupe_list]))
