# -*- coding: utf-8 -*-
from django.utils.translation import gettext as _

from creme.creme_core.core.entity_cell import EntityCellRegularField as ecrf
from creme.creme_core.gui.custom_form import (
    EntityCellCustomFormSpecial as eccfs,
)
from creme.creme_core.models import CustomFormConfigItem
from creme.persons import custom_forms, get_organisation_model
from creme.persons.forms.address import AddressesGroup

from center_pilote.populate_utils import Populate


class PopulateForm(Populate):
    model = get_organisation_model()

    def remove_existing(self):
        pass

    def is_already_populated(self):
        self.populate_clue = "Informations société"
        populate_test = ''
        if not self.overwrite:
            try:
                populate_test = (
                    CustomFormConfigItem.objects.filter(
                        pk__startswith='persons-organisation'
                    )
                    .first()
                    .groups_as_dicts()[0]
                    .get('name')
                )
            except (AttributeError, IndexError):
                pass
        return populate_test == self.populate_clue

    def _mk_group_ecrf(self, name, fields):
        "build a form with EntityCellRegularField"
        return {
            'name': name,
            'cells': [(ecrf, {'name': field}) for field in fields],
        }

    def populate(self):
        CustomFormConfigItem.objects.filter(
            pk__startswith='persons-organisation'
        ).delete()

        cfields_group_desc = {
            'name': _('Custom fields'),
            'cells': [
                (
                    eccfs,
                    {'name': eccfs.REMAINING_CUSTOMFIELDS},
                ),
            ],
        }
        creation_only_groups_desc = [
            {
                'name': _('Properties'),
                'cells': [
                    (
                        eccfs,
                        {'name': eccfs.CREME_PROPERTIES},
                    ),
                ],
            },
            {
                'name': _('Relationships'),
                'cells': [
                    (
                        eccfs,
                        {'name': eccfs.RELATIONS},
                    ),
                ],
            },
        ]
        orga_groups_desc = [
            self._mk_group_ecrf(
                name=self.populate_clue,
                fields=(
                    'user',
                    'name',
                    'image',
                    'activite',
                    'activite_secondaire',
                    'staff_size',
                    'naf',
                    'siret',
                    'siren',
                    'legal_form',
                    'capital',
                ),
            ),
            self._mk_group_ecrf(
                name="Contacts de l'organisation",
                fields=(
                    'phone',
                    'email',
                    'url_site',
                    'fax',
                ),
            ),
            AddressesGroup(model=self.model),
            cfields_group_desc,
        ]
        CustomFormConfigItem.objects.create_if_needed(
            descriptor=custom_forms.ORGANISATION_CREATION_CFORM,
            groups_desc=[
                *orga_groups_desc,
                *creation_only_groups_desc,
            ],
        )
        CustomFormConfigItem.objects.create_if_needed(
            descriptor=custom_forms.ORGANISATION_EDITION_CFORM,
            groups_desc=orga_groups_desc,
        )
