import logging

from creme.creme_core.core.entity_cell import EntityCellFunctionField as ecff
from creme.creme_core.core.entity_cell import EntityCellRegularField as ecrf
from creme.creme_core.core.entity_cell import EntityCellRelation as ecrl
from creme.creme_core.models import HeaderFilter
from creme.persons import get_organisation_model

from center_pilote.populate_utils import Populate

from .. import constants

logger = logging.getLogger(__name__)


class PopulateOrgHeaderFilter(Populate):
    """
    Create HeaderFilter(s) for organisation
    """

    model = get_organisation_model()

    def remove_existing(self):
        HeaderFilter.objects.filter(pk=constants.MY_HFILTER_ORGA).delete()

    def is_already_populated(self):
        rt = HeaderFilter.objects.filter(pk=constants.MY_HFILTER_ORGA).exists()
        return rt

    def populate(self):
        create_hf = HeaderFilter.objects.create_if_needed
        create_hf(
            pk=constants.MY_HFILTER_ORGA,
            model=self.model,
            name="Vue organisations",
            cells_desc=[
                (ecrf, {'name': 'name'}),
                (ecrf, {'name': 'phone'}),
                (ecrf, {'name': 'user'}),
                (ecrl, {'rtype_id': constants.REL_OBJ_MANAGES}),
                (ecff, {'func_field_name': 'org-adherente'}),
                (ecff, {'func_field_name': 'org-annee-adhesion'}),
                (ecff, {'func_field_name': 'org-type-adhesion'}),
            ],
        )
