# -*- coding: utf-8 -*-

import logging

from django.db.models import signals
from django.dispatch import receiver

from creme.activities.constants import (
    REL_SUB_ACTIVITY_SUBJECT,
    REL_SUB_PART_2_ACTIVITY,
)
from creme.activities.utils import is_auto_orga_subject_enabled
from creme.creme_core.models import Relation
from creme.persons import get_organisation_model

from .constants import ROLE_EMPLOYERS_PART

logger = logging.getLogger(__name__)
Organisation = get_organisation_model()


@receiver(signals.post_save, sender=Relation)
def _set_orga_as_subject_wide(sender, instance, **kwargs):
    if instance.type_id != REL_SUB_PART_2_ACTIVITY:
        return

    # NB: when a Relation is created, it is saved twice in order to set the link
    #     with its symmetric instance
    if instance.symmetric_relation_id is None:
        return

    activity = instance.object_entity.get_real_entity()

    if not is_auto_orga_subject_enabled():
        return

    user = instance.user
    Relation.objects.safe_multi_save(
        Relation(
            subject_entity=orga,
            type_id=REL_SUB_ACTIVITY_SUBJECT,
            object_entity=activity,
            user=user,
        )
        for orga in Organisation.objects.filter(
            relations__type__in=ROLE_EMPLOYERS_PART,
            relations__object_entity=instance.subject_entity_id,
        ).exclude(is_deleted=False, is_managed=True)
    )
