"""
Test that custom Brick (LimitedRelationBrick) behave correctly
TODO:
 - test include_ids, exclude_ids, include_sym
"""
import pytest

from center_pilote.pilote_extended.bricks import LimitedRelationsBrick

from .factories import OrganisationFactory, UserFactory

P = pytest.param


class DummyState:
    is_open = True
    show_empty_fields = False


class DummyBrickManager:
    @staticmethod
    def get_state(id, context):
        return DummyState

    def brick_is_registered(self):
        return True


class DummySession(dict):
    modified = False


@pytest.fixture
def minimal_brick_context(rf):
    req = rf.get('/')
    dummy_serialized_context = {
        '/': {'block_creme_core-relations': {}},
    }
    req.session = DummySession(brickcontexts_manager=dummy_serialized_context)
    context = {
        'object': OrganisationFactory.create(),
        'request': req,
        'bricks_manager': DummyBrickManager,
        'user': UserFactory.create(is_superuser=True),
    }
    return context


@pytest.mark.django_db
class TestLimitedRelationBrick:
    """
    really minimalist test that only pass through a LimitedRelationBrick
    It means to be a minimal check: if this test pass, then we can
    write more complex tests, in other words, do not try to repair other
    tests while this one do not pass
    """

    def test_detailview_display_min(self, minimal_brick_context):
        dummy_brick = LimitedRelationsBrick()
        ret = dummy_brick.detailview_display(minimal_brick_context)
        assert isinstance(ret, str)
