import pytest

from center_pilote.pilote_extended.models import Organisation
from center_pilote.pilote_extended.models.fields import phone_repr

DUMMY_ID = 1234


@pytest.mark.parametrize(
    'val, exp',
    [
        pytest.param('18', '18', id="simple 2 digits"),
        pytest.param('911', '911', id="simple 3 digits"),
        pytest.param('3919', '39.19', id="4 digits"),
        pytest.param('12345', '1.23.45', id="5 digits"),
        pytest.param(
            '0   10. 203 04--05', '01.02.03.04.05', id="10 digits w symbols"
        ),
        pytest.param('+33102030405', '+33 1.02.03.04.05', id="fr int. +"),
        pytest.param('0033102030405', '0033 1.02.03.04.05', id="fr int. 00"),
    ],
)
def test_phone_repr(val, exp):
    assert phone_repr(val) == exp


def test_organisation_get_phone_display():
    # entity_type_id is just here to avoid a ContentType request
    # cf: creme_core/models/entity.py:CremeEntity:__init__():112
    org = Organisation(entity_type_id=DUMMY_ID, phone='1234567890')
    assert org.get_phone_display() == '12.34.56.78.90'
