import datetime
import os
from io import StringIO

from django.core.management import call_command

import pytest

wip = pytest.mark.wip
# pytestmark = wip

TEST_FILE = '/dev/shm/test_gen_relations.txt'

INPUT = """maitre jedi\tjedi
padawan\tjedi
bidochon
"""

EXP_OUTPUT = """# file generated at {timestamp}
# from file {TEST_FILE}

REL_SUB_MAITRE_JEDI = 'pilote_extended-subject_maitre_jedi'
REL_OBJ_MAITRE_JEDI = 'pilote_extended-object_maitre_jedi'

REL_SUB_PADAWAN = 'pilote_extended-subject_padawan'
REL_OBJ_PADAWAN = 'pilote_extended-object_padawan'

REL_SUB_BIDOCHON = 'pilote_extended-subject_bidochon'
REL_OBJ_BIDOCHON = 'pilote_extended-object_bidochon'


SIMPLE_RELATIONS_LIST = [
    (
        (REL_SUB_MAITRE_JEDI, "est un maitre jedi de"),
        (REL_OBJ_MAITRE_JEDI, "a pour maitre jedi"),
    ),
    (
        (REL_SUB_PADAWAN, "est un padawan de"),
        (REL_OBJ_PADAWAN, "a pour padawan"),
    ),
    (
        (REL_SUB_BIDOCHON, "est un bidochon de"),
        (REL_OBJ_BIDOCHON, "a pour bidochon"),
    ),
]

ROLE_SUB_JEDI = {{
    REL_SUB_MAITRE_JEDI,
    REL_SUB_PADAWAN,
}}

ROLE_SUB_NA = {{
    REL_SUB_BIDOCHON,
}}

ROLE_OBJ_JEDI = {{
    REL_OBJ_MAITRE_JEDI,
    REL_OBJ_PADAWAN,
}}

ROLE_OBJ_NA = {{
    REL_OBJ_BIDOCHON,
}}
"""


def test_gen_relations():
    out = StringIO()
    with open(TEST_FILE, 'w') as test_file:
        test_file.write(INPUT)
    call_command('gen_relations', TEST_FILE, stdout=out)
    result_value = out.getvalue()
    os.remove(TEST_FILE)
    format_var = {
        'timestamp': datetime.datetime.now().strftime('%Y-%m-%d %H:%M'),
        'TEST_FILE': TEST_FILE,
    }
    assert result_value == EXP_OUTPUT.format(**format_var)
