from io import StringIO

from django.core.management import call_command

import pytest

from center_pilote.populate_utils import Populate

P = pytest.param


class TestPopulateBrick:
    @pytest.mark.parametrize(
        'overwrite, existing_pop, exp_pop',
        [
            P(False, False, True, id='Empty base -> populate'),
            P(True, False, True, id='Empty base, overwrite -> populate'),
            P(False, True, False, id='base set -> no populate'),
            P(True, True, True, id='base set, overwrite -> populate'),
        ],
    )
    def test_basic_Populate(self, overwrite, existing_pop, exp_pop):
        instance = Populate(overwrite=overwrite)
        instance.already_populated = existing_pop
        ret = instance.run()
        assert ret == exp_pop


@pytest.mark.parametrize(
    'overwrite', [P(True, id='overwrite'), P(False, id='no overwrite')]
)
@pytest.mark.parametrize(
    'appname', ['pilote_extended', 'info_tables', 'filiere_bois', 'bleach']
)
@pytest.mark.django_db
def test_populate(appname, overwrite, settings):
    settings.POPULATE_OVERWRITE = overwrite
    err = StringIO()
    call_command('creme_populate', appname, stderr=err)
    assert not err.getvalue()
